<?php
/**
 * Plugin Name: QSM - Advertisement Be Gone
 * Plugin URI: https://quizandsurveymaster.com/
 * Description: Remove all services/addon advertisements and news in Quiz And Survey Master
 * Author: Frank Corso
 * Author URI: https://quizandsurveymaster.com/
 * Version: 2.0.0
 *
 * @author Frank Corso
 * @version 2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * This class is the main class of the plugin
 *
 * When loaded, it loads the included plugin files and add functions to hooks or filters. The class also handles the admin menu
 *
 * @since 2.0.0
 */
class QSM_Advertisement_Be_Gone {

	/**
	 * Version Number
	 *
	 * @var string
	 * @since 2.0.0
	 */
	public $version = '2.0.0';

	/**
	 * Main Construct Function
	 *
	 * Call functions within class
	 *
	 * @since 2.0.0
	 * @uses QSM_Advertisement_Be_Gone::load_dependencies() Loads required filed
	 * @uses QSM_Advertisement_Be_Gone::add_hooks() Adds actions to hooks and filters
	 * @return void
	 */
	public function __construct() {
		$this->load_dependencies();
		$this->add_hooks();
		$this->check_license();
	}

	/**
	 * Load File Dependencies
	 *
	 * @since 2.0.0
	 * @return void
	 */
	public function load_dependencies() {
		include 'php/addon-settings-tab-content.php';
	}

	/**
	 * Add Hooks
	 *
	 * Adds functions to relavent hooks and filters
	 *
	 * @since 2.0.0
	 * @return void
	 */
	public function add_hooks() {
		add_action( 'admin_init', array( $this, 'set_ads' ) );
		add_action( 'admin_init', 'qsm_addon_advertisement_be_gone_register_addon_settings_tabs' );
	}

	/**
	 * Disables the ads
	 * 
	 * @since 2.0.0
	 * @return void  
	 */
	public function set_ads() {
		update_option( 'mlw_advert_shows' , 'false' );
	}

	/**
	 * Checks license
	 *
	 * Checks to see if license is active and, if so, checks for updates
	 *
	 * @since 2.0.0
	 * @return void
	 */
	public function check_license() {
		if ( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
			include 'php/EDD_SL_Plugin_Updater.php';
		}

		// Retrieve our license key from the DB.
		$addon_data = get_option( 'qsm_addon_advertisement_be_gone_settings', '' );
		if ( isset( $addon_data['license_key'] ) ) {
			$license_key = trim( $addon_data['license_key'] );
		} else {
			$license_key = '';
		}

		// Setup the updater.
		$edd_updater = new EDD_SL_Plugin_Updater( 'https://quizandsurveymaster.com', __FILE__, array(
			'version'   => $this->version,
			'license'   => $license_key,
			'item_name' => 'Advertisment Be Gone',
			'author'    => 'Frank Corso',
		));
	}
}

/**
 * Loads the addon if QSM is installed and activated
 *
 * @since 2.0.0
 */
function qsm_addon_advertisement_be_gone_load() {
	// Make sure QSM is active.
	if ( class_exists( 'MLWQuizMasterNext' ) ) {
		$qsm_advertisment_be_gone = new QSM_Advertisement_Be_Gone();
	} else {
		add_action( 'admin_notices', 'qsm_addon_advertisement_be_gone_missing_qsm' );
	}
}
add_action( 'plugins_loaded', 'qsm_addon_advertisement_be_gone_load' );

/**
 * Display notice if Quiz And Survey Master isn't installed
 *
 * @since 2.0.0
 */
function qsm_addon_advertisement_be_gone_missing_qsm() {
	echo '<div class="error"><p>QSM - Advertisment Be Gone requires Quiz And Survey Master. Please install and activate the Quiz And Survey Master plugin.</p></div>';
}

register_deactivation_hook( __FILE__, 'qsm_addon_advertisement_be_gone_deactivate' );

/**
 * When the addon gets deactivated, remove the option to hide the ads
 * 
 * @since 2.0.0
 */
function qsm_addon_advertisement_be_gone_deactivate() {
	delete_option( 'mlw_advert_shows' );
}
?>
